@@ -122,7 +122,6 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     connect(propertyLayout, SIGNAL(currentIndexChanged(int)),
             this, SLOT(propertyLayoutChanged(int)));
 
-    
 
     m_tuningFrequency = prefs->getTuningFrequency();
 
@@ -292,6 +291,14 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     connect(ttMode, SIGNAL(currentIndexChanged(int)),
             this, SLOT(timeToTextModeChanged(int)));
 
+    QCheckBox *hms = new QCheckBox;
+    int showHMS = prefs->getPropertyRangeAndValue
+        ("Show Hours And Minutes", &min, &max, &deflt);
+    m_showHMS = (showHMS != 0);
+    hms->setCheckState(m_showHMS ? Qt::Checked : Qt::Unchecked);
+    connect(hms, SIGNAL(stateChanged(int)),
+            this, SLOT(showHMSChanged(int)));
+    
     // General tab
 
     QFrame *frame = new QFrame;
@@ -341,6 +348,11 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     frame->setLayout(subgrid);
     row = 0;
 
+    subgrid->addWidget(new QLabel(tr("%1:").arg(prefs->getPropertyLabel
+                                                ("Show Splash Screen"))),
+                       row, 0);
+    subgrid->addWidget(showSplash, row++, 1, 1, 1);
+
     subgrid->addWidget(new QLabel(tr("%1:").arg(prefs->getPropertyLabel
                                                 ("Property Box Layout"))),
                        row, 0);
@@ -364,9 +376,9 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     subgrid->addWidget(ttMode, row++, 1, 1, 2);
 
     subgrid->addWidget(new QLabel(tr("%1:").arg(prefs->getPropertyLabel
-                                                ("Show Splash Screen"))),
+                                                ("Show Hours And Minutes"))),
                        row, 0);
-    subgrid->addWidget(showSplash, row++, 1, 1, 1);
+    subgrid->addWidget(hms, row++, 1, 1, 1);
 
     subgrid->setRowStretch(row, 10);
     
@@ -608,6 +620,13 @@ PreferencesDialog::timeToTextModeChanged(int mode)
     m_applyButton->setEnabled(true);
 }
 
+void
+PreferencesDialog::showHMSChanged(int state)
+{
+    m_showHMS = (state == Qt::Checked);
+    m_applyButton->setEnabled(true);
+}
+
 void
 PreferencesDialog::octaveSystemChanged(int system)
 {
@@ -647,6 +666,7 @@ PreferencesDialog::applyClicked()
     prefs->setTemporaryDirectoryRoot(m_tempDirRoot);
     prefs->setBackgroundMode(Preferences::BackgroundMode(m_backgroundMode));
     prefs->setTimeToTextMode(Preferences::TimeToTextMode(m_timeToTextMode));
+    prefs->setShowHMS(m_showHMS);
     prefs->setViewFontSize(m_viewFontSize);
     
     prefs->setProperty("Octave Numbering System", m_octaveSystem);
