@@ -21,19 +21,22 @@
 class PlaySpeedRangeMapper : public RangeMapper
 {
 public:
-    PlaySpeedRangeMapper(int minpos, int maxpos);
+    PlaySpeedRangeMapper();
 
-    virtual int getPositionForValue(float value) const;
-    virtual int getPositionForValueUnclamped(float value) const;
+    int getMinPosition() const { return m_minpos; }
+    int getMaxPosition() const { return m_maxpos; }
+    
+    virtual int getPositionForValue(double value) const;
+    virtual int getPositionForValueUnclamped(double value) const;
 
-    virtual float getValueForPosition(int position) const;
-    virtual float getValueForPositionUnclamped(int position) const;
+    virtual double getValueForPosition(int position) const;
+    virtual double getValueForPositionUnclamped(int position) const;
 
-    int getPositionForFactor(float factor) const;
-    float getValueForFactor(float factor) const;
+    int getPositionForFactor(double factor) const;
+    double getValueForFactor(double factor) const;
 
-    float getFactorForPosition(int position) const;
-    float getFactorForValue(float value) const;
+    double getFactorForPosition(int position) const;
+    double getFactorForValue(double value) const;
 
     virtual QString getUnit() const;
     
