@@ -51,9 +51,15 @@ Document::Document() :
     m_mainModel(0),
     m_autoAlignment(false)
 {
-    connect(this, SIGNAL(modelAboutToBeDeleted(Model *)),
+    connect(this,
+            SIGNAL(modelAboutToBeDeleted(Model *)),
             ModelTransformerFactory::getInstance(),
             SLOT(modelAboutToBeDeleted(Model *)));
+
+    connect(ModelTransformerFactory::getInstance(),
+            SIGNAL(transformFailed(QString, QString)),
+            this,
+            SIGNAL(modelGenerationFailed(QString, QString)));
 }
 
 Document::~Document()
@@ -734,7 +740,7 @@ Document::addDerivedModels(const Transforms &transforms,
         applied.setPluginVersion
             (TransformFactory::getInstance()->
              getDefaultTransformFor(applied.getIdentifier(),
-                                    lrintf(applied.getSampleRate()))
+                                    applied.getSampleRate())
              .getPluginVersion());
 
         if (!model) {
