@@ -30,6 +30,8 @@
 
 #include <QWriteLocker>
 
+#include <stdexcept>
+
 //#define DEBUG_FFT_SERVER 1
 //#define DEBUG_FFT_SERVER_FILL 1
 
@@ -53,7 +55,7 @@ FFTDataServer::getInstance(const DenseTimeValueModel *model,
                            int fftSize,
                            bool polar,
                            StorageAdviser::Criteria criteria,
-                           int fillFromColumn)
+                           sv_frame_t fillFromFrame)
 {
     QString n = generateFileBasename(model,
                                      channel,
@@ -93,7 +95,7 @@ FFTDataServer::getInstance(const DenseTimeValueModel *model,
                                    fftSize,
                                    polar,
                                    criteria,
-                                   fillFromColumn);
+                                   fillFromFrame);
     } catch (InsufficientDiscSpace) {
         delete server;
         server = 0;
@@ -115,7 +117,7 @@ FFTDataServer::getFuzzyInstance(const DenseTimeValueModel *model,
                                 int fftSize,
                                 bool polar,
                                 StorageAdviser::Criteria criteria,
-                                int fillFromColumn)
+                                sv_frame_t fillFromFrame)
 {
     // Fuzzy matching:
     // 
@@ -221,7 +223,7 @@ FFTDataServer::getFuzzyInstance(const DenseTimeValueModel *model,
                        fftSize,
                        polar,
                        criteria,
-                       fillFromColumn);
+                       fillFromFrame);
 }
 
 FFTDataServer *
@@ -488,7 +490,7 @@ FFTDataServer::FFTDataServer(QString fileBaseName,
 			     int fftSize,
                              bool polar,
                              StorageAdviser::Criteria criteria,
-                             int fillFromColumn) :
+                             sv_frame_t fillFromFrame) :
     m_fileBaseName(fileBaseName),
     m_model(model),
     m_channel(channel),
@@ -514,10 +516,10 @@ FFTDataServer::FFTDataServer(QString fileBaseName,
 
     //!!! end is not correct until model finished reading -- what to do???
 
-    int start = m_model->getStartFrame();
-    int end = m_model->getEndFrame();
+    sv_frame_t start = m_model->getStartFrame();
+    sv_frame_t end = m_model->getEndFrame();
 
-    m_width = (end - start) / m_windowIncrement + 1;
+    m_width = int((end - start) / m_windowIncrement) + 1;
     m_height = m_fftSize / 2 + 1; // DC == 0, Nyquist == fftsize/2
 
 #ifdef DEBUG_FFT_SERVER 
@@ -526,8 +528,8 @@ FFTDataServer::FFTDataServer(QString fileBaseName,
 #endif
 
     int maxCacheSize = 20 * 1024 * 1024;
-    int columnSize = m_height * sizeof(fftsample) * 2 + sizeof(fftsample);
-    if (m_width * columnSize < maxCacheSize * 2) m_cacheWidth = m_width;
+    int columnSize = int(m_height * sizeof(fftsample) * 2 + sizeof(fftsample));
+    if (m_width < ((maxCacheSize * 2) / columnSize)) m_cacheWidth = m_width;
     else m_cacheWidth = maxCacheSize / columnSize;
     
 #ifdef DEBUG_FFT_SERVER
@@ -585,7 +587,7 @@ FFTDataServer::FFTDataServer(QString fileBaseName,
         throw(0);
     }
 
-    m_fillThread = new FillThread(*this, fillFromColumn);
+    m_fillThread = new FillThread(*this, fillFromFrame);
 }
 
 FFTDataServer::~FFTDataServer()
@@ -681,9 +683,10 @@ void
 FFTDataServer::getStorageAdvice(int w, int h,
                                 bool &memoryCache, bool &compactCache)
 {
-    int cells = w * h;
-    int minimumSize = (cells / 1024) * sizeof(uint16_t); // kb
-    int maximumSize = (cells / 1024) * sizeof(float); // kb
+    if (w < 0 || h < 0) throw std::domain_error("width & height must be non-negative");
+    size_t cells = size_t(w) * h;
+    size_t minimumSize = (cells / 1024) * sizeof(uint16_t); // kb
+    size_t maximumSize = (cells / 1024) * sizeof(float); // kb
 
     // We don't have a compact rectangular representation, and compact
     // of course is never precision-critical
@@ -899,6 +902,7 @@ FFTDataServer::getMagnitudeAt(int x, int y)
         if (!cache) return 0;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getMagnitudeAt: filling");
 #ifdef DEBUG_FFT_SERVER
             std::cerr << "FFTDataServer::getMagnitudeAt: calling fillColumn("
@@ -935,6 +939,7 @@ FFTDataServer::getMagnitudesAt(int x, float *values, int minbin, int count, int
         if (!cache) return false;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getMagnitudesAt: filling");
             fillColumn(x);
         }
@@ -965,6 +970,7 @@ FFTDataServer::getNormalizedMagnitudeAt(int x, int y)
         if (!cache) return 0;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getNormalizedMagnitudeAt: filling");
             fillColumn(x);
         }
@@ -997,6 +1003,7 @@ FFTDataServer::getNormalizedMagnitudesAt(int x, float *values, int minbin, int c
         if (!cache) return false;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getNormalizedMagnitudesAt: filling");
             fillColumn(x);
         }
@@ -1029,6 +1036,7 @@ FFTDataServer::getMaximumMagnitudeAt(int x)
         if (!cache) return 0;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getMaximumMagnitudeAt: filling");
             fillColumn(x);
         }
@@ -1057,6 +1065,7 @@ FFTDataServer::getPhaseAt(int x, int y)
         if (!cache) return 0;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getPhaseAt: filling");
             fillColumn(x);
         }
@@ -1089,6 +1098,7 @@ FFTDataServer::getPhasesAt(int x, float *values, int minbin, int count, int step
         if (!cache) return false;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getPhasesAt: filling");
             fillColumn(x);
         }
@@ -1128,6 +1138,11 @@ FFTDataServer::getValuesAt(int x, int y, float &real, float &imaginary)
         }
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") {
+                real = 0;
+                imaginary = 0;
+                return;
+            }
             Profiler profiler("FFTDataServer::getValuesAt: filling");
 #ifdef DEBUG_FFT_SERVER
             std::cerr << "FFTDataServer::getValuesAt(" << x << ", " << y << "): filling" << std::endl;
@@ -1162,6 +1177,7 @@ FFTDataServer::getValuesAt(int x, float *reals, float *imaginaries, int minbin,
         if (!cache) return false;
 
         if (!cache->haveSetColumnAt(col)) {
+            if (getError() != "") return false;
             Profiler profiler("FFTDataServer::getValuesAt: filling");
             fillColumn(x);
         }
@@ -1248,12 +1264,14 @@ FFTDataServer::fillColumn(int x)
     int fftsize = m_fftSize;
     int hs = fftsize/2;
 
-    int pfx = 0;
+    sv_frame_t pfx = 0;
     int off = (fftsize - winsize) / 2;
 
-    int startFrame = m_windowIncrement * x;
-    int endFrame = startFrame + m_windowSize;
+    sv_frame_t startFrame = m_windowIncrement * sv_frame_t(x);
+    sv_frame_t endFrame = startFrame + m_windowSize;
 
+    // FFT windows are centred at the respective audio sample frame,
+    // so the first one is centred at 0
     startFrame -= winsize / 2;
     endFrame   -= winsize / 2;
 
@@ -1300,11 +1318,11 @@ FFTDataServer::fillColumn(int x)
 	}
     }
 
-    int count = 0;
+    sv_frame_t count = 0;
     if (endFrame > startFrame + pfx) count = endFrame - (startFrame + pfx);
 
-    int got = m_model->getData(m_channel, startFrame + pfx,
-                               count, m_fftInput + off + pfx);
+    sv_frame_t got = m_model->getData(m_channel, startFrame + pfx,
+                                      count, m_fftInput + off + pfx);
 
     while (got + pfx < winsize) {
 	m_fftInput[off + got + pfx] = 0.0;
@@ -1315,7 +1333,7 @@ FFTDataServer::fillColumn(int x)
 	int channels = m_model->getChannelCount();
 	if (channels > 1) {
 	    for (int i = 0; i < winsize; ++i) {
-		m_fftInput[off + i] /= channels;
+		m_fftInput[off + i] /= float(channels);
 	    }
 	}
     }
@@ -1392,9 +1410,19 @@ FFTDataServer::fillComplete()
 QString
 FFTDataServer::getError() const
 {
-    if (m_error != "") return m_error;
-    else if (m_fillThread) return m_fillThread->getError();
-    else return "";
+    QString err;
+    if (m_error != "") {
+        err = m_error;
+//        cerr << "FFTDataServer::getError: err (server " << this << ") = " << err << endl;
+    } else {
+        MutexLocker locker(&m_fftBuffersLock, "FFTDataServer::getError");
+        if (m_fillThread) {
+            err = m_fillThread->getError();
+//            cerr << "FFTDataServer::getError: err (server " << this << ", from thread " << m_fillThread
+//                 << ") = " << err << endl;
+        }
+    }
+    return err;
 }
 
 int
@@ -1404,7 +1432,7 @@ FFTDataServer::getFillCompletion() const
     else return 100;
 }
 
-int
+sv_frame_t
 FFTDataServer::getFillExtent() const
 {
     if (m_fillThread) return m_fillThread->getExtent();
@@ -1456,24 +1484,26 @@ FFTDataServer::FillThread::run()
     }
     if (m_server.m_exiting) return;
 
-    int start = m_server.m_model->getStartFrame();
-    int end = m_server.m_model->getEndFrame();
-    int remainingEnd = end;
+    sv_frame_t start = m_server.m_model->getStartFrame();
+    sv_frame_t end = m_server.m_model->getEndFrame();
+    sv_frame_t remainingEnd = end;
 
     int counter = 0;
     int updateAt = 1;
-    int maxUpdateAt = (end / m_server.m_windowIncrement) / 20;
+    int maxUpdateAt = int(end / m_server.m_windowIncrement) / 20;
     if (maxUpdateAt < 100) maxUpdateAt = 100;
 
     if (m_fillFrom > start) {
 
-        for (int f = m_fillFrom; f < end; f += m_server.m_windowIncrement) {
+        for (sv_frame_t f = m_fillFrom; f < end; f += m_server.m_windowIncrement) {
 	    
             try {
                 m_server.fillColumn(int((f - start) / m_server.m_windowIncrement));
             } catch (std::exception &e) {
-                std::cerr << "FFTDataServer::FillThread::run: exception: " << e.what() << std::endl;
-                m_error = e.what();
+                MutexLocker locker(&m_server.m_fftBuffersLock,
+                                   "FFTDataServer::run::m_fftBuffersLock [err]");
+                m_threadError = e.what();
+                std::cerr << "FFTDataServer::FillThread::run: exception: " << m_threadError << " (thread = " << this << " from server " << &m_server << ")" << std::endl;
                 m_server.fillComplete();
                 m_completion = 100;
                 m_extent = end;
@@ -1516,13 +1546,15 @@ FFTDataServer::FillThread::run()
 
     int baseCompletion = m_completion;
 
-    for (int f = start; f < remainingEnd; f += m_server.m_windowIncrement) {
+    for (sv_frame_t f = start; f < remainingEnd; f += m_server.m_windowIncrement) {
 
         try {
             m_server.fillColumn(int((f - start) / m_server.m_windowIncrement));
         } catch (std::exception &e) {
-            std::cerr << "FFTDataServer::FillThread::run: exception: " << e.what() << std::endl;
-            m_error = e.what();
+            MutexLocker locker(&m_server.m_fftBuffersLock,
+                               "FFTDataServer::run::m_fftBuffersLock [err]");
+            m_threadError = e.what();
+                std::cerr << "FFTDataServer::FillThread::run: exception: " << m_threadError << " (thread = " << this << " from server " << &m_server << ")" << std::endl;
             m_server.fillComplete();
             m_completion = 100;
             m_extent = end;
